@@ -1,8 +1,13 @@
-# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# Copyright (c) 2016-2024 Association of Universities for Research in Astronomy, Inc. (AURA)
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
 import numpy as np
 
+__all__ = [
+    'scalar_input',
+    'immutable',
+]
+
 
 def scalar_input(func):
     """
