@@ -1,16 +1,17 @@
-# Copyright (c) 2016-2023 Association of Universities for Research in Astronomy, Inc. (AURA)
+# Copyright (c) 2016-2024 Association of Universities for Research in Astronomy, Inc. (AURA)
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
 from __future__ import annotations
 
 from dataclasses import dataclass, field
 from enum import Enum, IntEnum, auto
-from typing import ClassVar, List, Optional, Sequence
+from typing import ClassVar, List, Optional, Sequence, final
 
 import numpy as np
 import numpy.typing as npt
 from astropy.coordinates import Angle
 from astropy.units import Quantity
+from astropy import units as u
 
 from lucupy.helpers import flatten
 from lucupy.types import ScalarOrNDArray
@@ -18,7 +19,21 @@ from lucupy.types import ScalarOrNDArray
 from ..decorators import immutable
 from .timingwindow import TimingWindow
 
+__all__ = [
+    'CloudCover',
+    'Conditions',
+    'Constraints',
+    'ElevationType',
+    'ImageQuality',
+    'SkyBackground',
+    'Strehl',
+    'Variant',
+    'VariantSnapshot',
+    'WaterVapor',
+]
 
+
+@final
 class SkyBackground(float, Enum):
     """
     Bins for observation sky background requirements or current conditions.
@@ -36,6 +51,7 @@ class SkyBackground(float, Enum):
     SBANY = 1.0
 
 
+@final
 class CloudCover(float, Enum):
     """
     Bins for observation cloud cover requirements or current conditions.
@@ -52,6 +68,7 @@ class CloudCover(float, Enum):
     CCANY = 1.0
 
 
+@final
 class ImageQuality(float, Enum):
     """
     Bins for observation image quality requirements or current conditions.
@@ -69,6 +86,7 @@ class ImageQuality(float, Enum):
     IQANY = 1.0
 
 
+@final
 class WaterVapor(float, Enum):
     """
     Bins for observation water vapor requirements or current conditions.
@@ -86,6 +104,7 @@ class WaterVapor(float, Enum):
     WVANY = 1.0
 
 
+@final
 class Strehl(float, Enum):
     """
     The Strehl ratio is a measure of the quality of optical image formation.
@@ -110,6 +129,7 @@ class Strehl(float, Enum):
     S10 = 1.0
 
 
+@final
 class ElevationType(IntEnum):
     """
     The type of elevation constraints in the observing conditions.
@@ -124,6 +144,7 @@ class ElevationType(IntEnum):
     AIRMASS = auto()
 
 
+@final
 @immutable
 @dataclass(frozen=True)
 class Conditions:
@@ -195,6 +216,7 @@ class Conditions:
         return len(self.cc) if isinstance(self.cc, np.ndarray) else 1
 
 
+@final
 @immutable
 @dataclass(frozen=True)
 class Constraints:
@@ -231,22 +253,18 @@ class Constraints:
     DEFAULT_AIRMASS_ELEVATION_MAX: ClassVar[float] = field(init=False, default=2.3, repr=False, compare=False)
 
 
+@final
 @immutable
 @dataclass(frozen=True)
 class Variant:
-    """A weather variant.
-    wind_speed should be in m / s.
-
+    """
+    A weather variant.
     Attributes:
         iq (Union[npt.NDArray[ImageQuality], ImageQuality]): Image quality.
         cc (Union[npt.NDArray[CloudCover], CloudCover]): Cloud Cover.
-        wind_dir (Angle): Wind direction.
-        wind_spd (Quantity): Wind speed.
-
+        wind_dir (Angle): Wind direction (degrees).
+        wind_spd (Quantity): Wind speed (m/s).
     """
-    # TODO: No idea what time blocks are. Note this could be a list or a single value.
-    # TODO: Because of this, we cannot hash Variants, which is problematic.
-
     iq: npt.NDArray[ImageQuality] | ImageQuality
     cc: npt.NDArray[CloudCover] | CloudCover
     wind_dir: Angle
@@ -269,3 +287,50 @@ class Variant:
             uniform_lengths = len(array_lengths) == 1
         if not uniform_lengths:
             raise ValueError(f'Variant has a variable number of array sizes: {self}')
+
+
+@final
+@immutable
+@dataclass(frozen=True)
+class VariantSnapshot:
+    """
+    A snapshot of a variant: this is used to keep track of weather changes or the current state of
+    the weather at a site.
+
+    wind_dir should be in degrees.
+    wind_speed should be in m / s.
+
+    Attributes:
+        iq (ImageQuality): Image quality.
+        cc (CloudCover): Cloud cover.
+        wind_dir (Angle): Wind direction (in degrees). Should be scalar.
+        wind_spd (Quantity): Wind speed (in m/s). Should be scalar.
+    """
+    iq: ImageQuality
+    cc: CloudCover
+    wind_dir: Angle
+    wind_spd: Quantity
+
+    def __post_init__(self):
+        if self.wind_dir.size != 1:
+            raise ValueError(f'Wind direction should be scalar, but has size {self.wind_dir.size}.')
+        if self.wind_spd.unit != u.m / u.s:
+            raise ValueError(f'Wind speed should be in m / s, but {self.wind_spd.unit} specified.')
+        if self.wind_spd.size != 1:
+            raise ValueError(f'Wind speed should be scalar, but has size {self.wind_spd.size}.')
+
+    def make_variant(self, num_timeslots: int) -> Variant:
+        """
+        Create a Variant object with the specified number of timeslots.
+        """
+        if num_timeslots <= 0:
+            raise ValueError(f'Request to make a Variant for illegal number of timeslots: {num_timeslots}.')
+
+        cc_array = np.array([self.cc] * num_timeslots)
+        iq_array = np.array([self.iq] * num_timeslots)
+        wind_dir_array = Angle(np.full(num_timeslots, self.wind_dir.value), unit=self.wind_dir.unit)
+        wind_spd_array = np.full(num_timeslots, self.wind_spd.value) * self.wind_spd.unit
+        return Variant(iq=iq_array,
+                       cc=cc_array,
+                       wind_dir=wind_dir_array,
+                       wind_spd=wind_spd_array)
