@@ -1,9 +1,15 @@
-# Copyright (c) 2016-2022 Association of Universities for Research in Astronomy, Inc. (AURA)
+# Copyright (c) 2016-2024 Association of Universities for Research in Astronomy, Inc. (AURA)
 # For license information see LICENSE or https://opensource.org/licenses/BSD-3-Clause
 
 from enum import IntEnum, auto
+from typing import final
+
+__all__ = [
+    'TooType',
+]
 
 
+@final
 class TooType(IntEnum):
     """
     The target-of-opportunity type for a program and for an observation.
